@@ -37,6 +37,7 @@ Other device options:
   --temperature-sensor <number>  The temperature sensor number for the Commander Pro
   --legacy-690lc                 Use Asetek 690LC in legacy mode (old Krakens)
   --non-volatile                 Store on non-volatile controller memory
+  --direct-access                Directly access the device despite kernel drivers
   --unsafe <features>            Comma-separated bleeding-edge features to enable
 
 Other interface options:
@@ -50,8 +51,8 @@ Deprecated:
   -d, --device <index>           Select device by listing index
   --hid <ignored>                Ignored
 
-Copyright (C) 2018–2021  Jonas Malaco, Marshall Asch, CaseySJ, Tom Frey, Andrew
-Robertson  and contributors
+Copyright (C) 2018–2022  Jonas Malaco, Marshall Asch, CaseySJ, Tom Frey, Andrew
+Robertson, ParkerMc and contributors
 
 liquidctl incorporates work by leaty, Ksenija Stanojevic, Alexander Tong, Jens
 Neumaier, Kristóf Jakab, Sean Nelson, Chris Griffith, notaz, realies and Thomas
@@ -70,6 +71,8 @@ import inspect
 import json
 import logging
 import os
+import platform
+import re
 import sys
 from numbers import Number
 from traceback import format_exception
@@ -77,10 +80,11 @@ from traceback import format_exception
 import colorlog
 from docopt import docopt
 
+from liquidctl import __version__
 from liquidctl.driver import *
 from liquidctl.error import NotSupportedByDevice, NotSupportedByDriver, UnsafeFeaturesNotEnabled
 from liquidctl.util import color_from_str
-from liquidctl.version import __version__
+
 
 # conversion from CLI arg to internal option; as options as forwarded to bused
 # and drivers, they must:
@@ -111,6 +115,7 @@ _PARSE_ARG = {
     '--pump-mode': str.lower,
     '--legacy-690lc': bool,
     '--non-volatile': bool,
+    '--direct-access': bool,
     '--unsafe': lambda x: x.lower().split(','),
     '--verbose': bool,
     '--debug': bool,
@@ -211,8 +216,8 @@ def _list_devices_human(devices, *, using_filters, device_id, verbose, debug, **
 
         print(f'└── Driver: {type(dev).__name__}')
         if debug:
-            driver_hier = [i.__name__ for i in inspect.getmro(type(dev)) if i != object]
-            _LOGGER.debug('hierarchy: %s', ', '.join(driver_hier[1:]))
+            driver_hier = (i.__name__ for i in inspect.getmro(type(dev)))
+            _LOGGER.debug('MRO: %s', ', '.join(driver_hier))
 
         for msg in warnings:
             _LOGGER.warning(msg)
@@ -295,33 +300,63 @@ def _make_opts(args):
     return opts
 
 
-def _gen_version():
-    extra = None
-    try:
-        from liquidctl.extraversion import __extraversion__
-        if __extraversion__['editable']:
-            extra = ['editable']
-        elif __extraversion__['dist_name'] and __extraversion__['dist_package']:
-            extra = [__extraversion__['dist_name'], __extraversion__['dist_package']]
+def _log_requirements():
+    _LOGGER.debug('python: %s', sys.version)
+    if sys.hexversion >= 0x03080000:
+        from importlib.metadata import distribution, version, PackageNotFoundError
+
+        try:
+            dist = distribution('liquidctl')
+        except PackageNotFoundError:
+            _LOGGER.debug('not installed, package metadata not available')
+            return
+
+        for req in dist.requires:
+            name = re.search('^[a-zA-Z0-9]([a-zA-Z0-9._-]*)', req).group(0)
+            try:
+                _LOGGER.debug('%s: %s', name, version(name))
+            except Exception as err:
+                _LOGGER.debug('%s: version n/a (%s)', name, err)
+    else:
+        _LOGGER.debug('importlib.metadata not available')
+
+
+class _ErrorAcc:
+    __slots__ = ['_errors']
+
+    def __init__(self):
+        self._errors = 0
+
+    def log(self, msg, *args, err=None, show_err=False):
+        self._errors += 1
+        if err:
+            # log the err with traceback before reporting it properly, this time
+            # without traceback; this puts error messages are at the bottom of the
+            # output, where most users first look for them
+            _LOGGER.info('detailed error: %s: %r', msg, err, *args, exc_info=True)
+
+        if show_err and err:
+            _LOGGER.error('%s: %r', msg, err, *args)
         else:
-            extra = [__extraversion__['commit'][:12]]
-            if __extraversion__['dirty']:
-                extra[0] += '-dirty'
-    except:
-        return f'liquidctl v{__version__}'
-    return f'liquidctl v{__version__} ({"; ".join(extra)})'
+            _LOGGER.error(msg, *args)
+
+    def exit_code(self):
+        return 0 if self.is_empty() else 1
+
+    def is_empty(self):
+        return not bool(self._errors)
 
 
 def main():
     args = docopt(__doc__)
 
     if args['--version']:
-        print(_gen_version())
+        print(f'liquidctl v{__version__} ({platform.platform()})')
         sys.exit(0)
 
     if args['--debug']:
         args['--verbose'] = True
-        log_fmt = '%(log_color)s[%(levelname)s] %(module)s (%(funcName)s): %(message)s'
+        log_fmt = '%(log_color)s[%(levelname)s] (%(module)s) (%(funcName)s): %(message)s'
         log_level = logging.DEBUG
     elif args['--verbose']:
         log_fmt = '%(log_color)s%(levelname)s: %(message)s'
@@ -355,7 +390,14 @@ def main():
     log_handler.setFormatter(log_fmtter)
     logging.basicConfig(level=log_level, handlers=[log_handler])
 
-    _LOGGER.debug('running %s', _gen_version())
+    _LOGGER.debug('liquidctl: %s', __version__)
+    _LOGGER.debug('platform: %s', platform.platform())
+    _log_requirements()
+
+    if __name__ == '__main__':
+        _LOGGER.warning('python -m liquidctl.cli is deprecated, prefer python -m liquidctl')
+
+    errors = _ErrorAcc()
 
     # unlike humans, machines want to know everything; imply verbose everywhere
     # other than when setting default logging level and format (which are
@@ -375,12 +417,14 @@ def main():
         no_filters = {opt: val for opt, val in opts.items() if opt not in _FILTER_OPTIONS}
         compat = list(find_liquidctl_devices(**no_filters))
         if device_id < 0 or device_id >= len(compat):
-            raise SystemExit('Error: device index out of bounds')
+            errors.log('device index out of bounds')
+            return errors.exit_code()
         if filter_count:
             # check that --device matches other filter criteria
             matched_devs = [dev.device for dev in find_liquidctl_devices(**opts)]
             if compat[device_id].device not in matched_devs:
-                raise SystemExit('Error: device index does not match remaining selection criteria')
+                errors.log('device index does not match remaining selection criteria')
+                return errors.exit_code()
             _LOGGER.warning('mixing --device <id> with other filters is not recommended; '
                             'to disambiguate between results prefer --pick <result>')
         selected = [compat[device_id]]
@@ -395,21 +439,11 @@ def main():
         return
 
     if len(selected) > 1 and not (args['status'] or args['all']):
-        raise SystemExit('Error: too many devices, filter or select one (see: liquidctl --help)')
+        errors.log('too many devices, filter or select one (see: liquidctl --help)')
+        return errors.exit_code()
     elif len(selected) == 0:
-        raise SystemExit('Error: no devices matches available drivers and selection criteria')
-
-    errors = 0
-
-    def log_error(err, msg, append_err=False, *args):
-        nonlocal errors
-        errors += 1
-        _LOGGER.info('%s', err, exc_info=True)
-        if append_err:
-            exception = list(format_exception(Exception, err, None))[-1].rstrip()
-            _LOGGER.error(f'{msg}: {exception}', *args)
-        else:
-            _LOGGER.error(msg, *args)
+        errors.log('no device matches available drivers and selection criteria')
+        return errors.exit_code()
 
     # for json
     obj_buf = []
@@ -440,39 +474,32 @@ def main():
             # each backend API returns a different subtype of OSError (OSError,
             # usb.core.USBError or PermissionError) for permission issues
             if err.errno in [errno.EACCES, errno.EPERM]:
-                log_error(err, f'Error: insufficient permissions to access {dev.description}')
+                errors.log(f'insufficient permissions to access {dev.description}', err=err)
             elif err.args == ('open failed', ):
-                log_error(err, f'Error: could not open {dev.description}, possibly due to insufficient permissions')
+                errors.log(
+                    f'could not open {dev.description}, possibly due to insufficient permissions',
+                    err=err
+                )
             else:
-                log_error(err, f'Unexpected OS error with {dev.description}', append_err=True)
+                errors.log(f'unexpected OS error with {dev.description}', err=err, show_err=True)
         except NotSupportedByDevice as err:
-            log_error(err, f'Error: operation not supported by {dev.description}')
+            errors.log(f'operation not supported by {dev.description}', err=err)
         except NotSupportedByDriver as err:
-            log_error(err, f'Error: operation not supported by driver for {dev.description}')
+            errors.log(f'operation not supported by driver for {dev.description}', err=err)
         except UnsafeFeaturesNotEnabled as err:
             features = ','.join(err.args)
-            log_error(err, f'Error: missing --unsafe features for {dev.description}: {features!r}')
-            _LOGGER.error('More information is provided in the corresponding device guide')
+            errors.log(f'missing --unsafe features for {dev.description}: {features!r}', err=err)
         except Exception as err:
-            log_error(err, f'Unexpected error with {dev.description}', append_err=True)
+            errors.log(f'unexpected error with {dev.description}', err=err, show_err=True)
 
-    if errors:
-        sys.exit(errors)
-
-    if args['--json']:
+    if errors.is_empty() and args['--json']:
         # use __str__ for values that cannot be directly serialized to JSON
         # (e.g. enums)
         print(json.dumps(obj_buf, ensure_ascii=(os.getenv('LANG', None) == 'C'),
                          default=lambda x: str(x)))
 
-    sys.exit(0)
-
-
-def find_all_supported_devices(**opts):
-    """Deprecated."""
-    _LOGGER.warning('deprecated: use liquidctl.driver.find_liquidctl_devices instead')
-    return find_liquidctl_devices(**opts)
+    return errors.exit_code()
 
 
 if __name__ == '__main__':
-    main()
+    sys.exit(main())
