@@ -8,7 +8,7 @@ Supported devices:
 - Corsair Hydro H80i GT, H100i GTX or H110i GTX
 - Corsair Hydro H80i v2, H100i v2 or H115i
 
-Copyright (C) 2018–2021  Jonas Malaco and contributors
+Copyright (C) 2018–2022  Jonas Malaco and contributors
 
 Incorporates or uses as reference work by Kristóf Jakab, Sean Nelson
 and Chris Griffith.
@@ -189,6 +189,17 @@ class _Base690Lc(UsbDriver):
 
 class _ModernBase690Lc(_Base690Lc):
 
+    def _persist(self):
+        _LOGGER.debug('instructing device to persist current settings')
+        self._begin_transaction()
+        self._write([_CMD_STORE_SETTINGS])
+        self._end_transaction_and_read()
+
+    def initialize(self, non_volatile=False, **kwargs):
+        super().initialize(**kwargs)
+        if non_volatile:
+            self._persist()
+
     def get_status(self, **kwargs):
         """Get a status report.
 
@@ -206,9 +217,9 @@ class _ModernBase690Lc(_Base690Lc):
             ('Firmware version', firmware, '')
         ]
 
-    def set_color(self, channel, mode, colors, time_per_color=1, time_off=None,
-                  alert_threshold=_HIGH_TEMPERATURE, alert_color=[255, 0, 0],
-                  speed=3, **kwargs):
+    def set_color(self, channel, mode, colors, time_per_color=1,
+                  time_off=None, alert_threshold=_HIGH_TEMPERATURE, alert_color=[255, 0, 0],
+                  speed=3, non_volatile=False, **kwargs):
         """Set the color mode for a specific channel."""
         # keyword arguments may have been forwarded from cli args and need parsing
         colors = list(colors)
@@ -242,8 +253,10 @@ class _ModernBase690Lc(_Base690Lc):
         else:
             raise KeyError(f'unknown lighting mode {mode}')
         self._end_transaction_and_read()
+        if non_volatile:
+            self._persist()
 
-    def set_speed_profile(self, channel, profile, **kwargs):
+    def set_speed_profile(self, channel, profile, non_volatile=False, **kwargs):
         """Set channel to follow a speed duty profile."""
         mtype, dmin, dmax = _VARIABLE_SPEED_CHANNELS[channel]
         adjusted = self._prepare_profile(profile, dmin, dmax, _MAX_PROFILE_POINTS)
@@ -254,8 +267,10 @@ class _ModernBase690Lc(_Base690Lc):
         self._begin_transaction()
         self._write([mtype, 0] + temps + duties)
         self._end_transaction_and_read()
+        if non_volatile:
+            self._persist()
 
-    def set_fixed_speed(self, channel, duty, **kwargs):
+    def set_fixed_speed(self, channel, duty, non_volatile=False, **kwargs):
         """Set channel to a fixed speed duty."""
         if channel == 'fan':
             # While devices seem to recognize a specific channel for fixed fan
@@ -265,7 +280,7 @@ class _ModernBase690Lc(_Base690Lc):
             # *another* call to initialize(), i.e.  with another
             # configuration command.
             _LOGGER.info('using a flat profile to set %s to a fixed duty', channel)
-            self.set_speed_profile(channel, [(0, duty), (_CRITICAL_TEMPERATURE - 1, duty)])
+            self.set_speed_profile(channel, [(0, duty), (_CRITICAL_TEMPERATURE - 1, duty)], non_volatile, **kwargs)
             return
         mtype, dmin, dmax = _FIXED_SPEED_CHANNELS[channel]
         duty = clamp(duty, dmin, dmax)
@@ -276,7 +291,8 @@ class _ModernBase690Lc(_Base690Lc):
         self._begin_transaction()
         self._write([mtype, _MIN_PUMP_SPEED_CODE + level])
         self._end_transaction_and_read()
-
+        if non_volatile:
+            self._persist()
 
 class Modern690Lc(_ModernBase690Lc):
     """Modern fifth generation Asetek 690LC cooler."""
@@ -351,6 +367,7 @@ class Legacy690Lc(_Base690Lc):
         self._data.store('pump_duty', None)
         self._data.store('fan_duty', None)
         self._set_all_fixed_speeds()
+        _warn_on_unsupported_option(**kwargs)
 
     def get_status(self, **kwargs):
         """Get a status report.
@@ -398,6 +415,7 @@ class Legacy690Lc(_Base690Lc):
         else:
             raise KeyError(f'unsupported lighting mode {mode}')
         self._end_transaction_and_read()
+        _warn_on_unsupported_option(**kwargs)
 
     def set_fixed_speed(self, channel, duty, **kwargs):
         """Set channel to a fixed speed duty."""
@@ -405,6 +423,7 @@ class Legacy690Lc(_Base690Lc):
         duty = clamp(duty, dmin, dmax)
         self._data.store(f'{channel}_duty', duty)
         self._set_all_fixed_speeds()
+        _warn_on_unsupported_option(**kwargs)
 
     def set_speed_profile(self, channel, profile, **kwargs):
         """Not supported by this device."""
@@ -430,6 +449,11 @@ class Hydro690Lc(_ModernBase690Lc):
         super().set_color(channel, mode, colors, **kwargs)
 
 
+def _warn_on_unsupported_option(**kwargs):
+    if kwargs.get('non_volatile'):
+        _LOGGER.warning('device does not support non-volatile settings, skipping')
+
+
 # deprecated aliases
 AsetekDriver = Modern690Lc
 LegacyAsetekDriver = Legacy690Lc
