@@ -41,7 +41,7 @@ _STATUS_FAN_SPEED = 'Fan speed'
 _STATUS_PUMP_SPEED = 'Pump speed'
 _STATUS_FWVERSION = 'Firmware version'
 
-# more aggressive than observed 4.0.3 and 6.0.2 firmware defaults
+# more aggressive than observed 4.0.3 and 6.2 firmware defaults
 _RESET_FAN_PROFILE = [(20, 25), (30, 50), (50, 90), (60, 100)]
 _RESET_PUMP_PROFILE = [(20, 50), (30, 60), (40, 90), (50, 100)]
 
@@ -133,48 +133,32 @@ class Kraken2(UsbHidDriver):
             self.set_speed_profile('fan', _RESET_FAN_PROFILE)
             self.set_speed_profile('pump', _RESET_PUMP_PROFILE)
 
-        firmware = '{}.{}.{}'.format(*self.firmware_version)
-        return [('Firmware version', firmware, '')]
+        fw = self.firmware_version
+        _LOGGER.debug('raw firmware version: %r', fw)
 
-    def _get_status_directly(self, with_firmware):
-        # the firmware version is duplicated here as a temporary migration aid
-        # for GKraken; it will be removed once GKraken no longer needs it, or
-        # in liquidctl 1.10.x, whatever happens first
+        # after the transition to the unified 5.x/6.x firmware, NZXT/CAM
+        # simplified how they report the firmware version from its raw
+        # 4-component form
+        fw_human = f'{fw[0]}.{fw[3]}' if fw[0] >= 5 else f'{fw[0]}.{fw[2]}.{fw[3]}'
+        return [('Firmware version', fw_human, '')]
 
+    def _get_status_directly(self):
         msg = self._read()
 
-        ret = [
+        return [
             (_STATUS_TEMPERATURE, msg[1] + msg[2]/10, '°C'),
             (_STATUS_FAN_SPEED, msg[3] << 8 | msg[4], 'rpm'),
             (_STATUS_PUMP_SPEED, msg[5] << 8 | msg[6], 'rpm'),
         ]
 
-        # TODO remove
-        if with_firmware:
-            firmware_version = '{}.{}.{}'.format(*self.firmware_version)
-            ret.append((_STATUS_FWVERSION, firmware_version, ''))
-
-        return ret
-
-    def _get_status_from_hwmon(self, with_firmware):
-        # the firmware version is duplicated here as a temporary migration aid
-        # for GKraken; it will be removed once GKraken no longer needs it, or
-        # in liquidctl 1.10.x, whatever happens first
-
-        ret = [
+    def _get_status_from_hwmon(self):
+        return [
             (_STATUS_TEMPERATURE, self._hwmon.get_int('temp1_input') * 1e-3, '°C'),
             (_STATUS_FAN_SPEED, self._hwmon.get_int('fan1_input'), 'rpm'),
             (_STATUS_PUMP_SPEED, self._hwmon.get_int('fan2_input'), 'rpm'),
         ]
 
-        # TODO remove
-        if with_firmware:
-            firmware_version = '{}.{}.{}'.format(*self.firmware_version)
-            ret.append((_STATUS_FWVERSION, firmware_version, ''))
-
-        return ret
-
-    def get_status(self, direct_access=False, *, _internal_called_from_cli=False, **kwargs):
+    def get_status(self, direct_access=False, **kwargs):
         """Get a status report.
 
         Returns a list of `(property, value, unit)` tuples.
@@ -183,18 +167,15 @@ class Kraken2(UsbHidDriver):
         if self.device_type == self.DEVICE_KRAKENM:
             return []
 
-        # already omit the firmware version when the caller is our own cli
-        with_firmware = not _internal_called_from_cli
-
         if self._hwmon and not direct_access:
             _LOGGER.info('bound to %s kernel driver, reading status from hwmon', self._hwmon.module)
-            return self._get_status_from_hwmon(with_firmware)
+            return self._get_status_from_hwmon()
 
         if self._hwmon:
             _LOGGER.warning('directly reading the status despite %s kernel driver',
                             self._hwmon.module)
 
-        return self._get_status_directly(with_firmware)
+        return self._get_status_directly()
 
     def set_color(self, channel, mode, colors, speed='normal', direction='forward', **kwargs):
         """Set the color mode for a specific channel."""
@@ -291,7 +272,7 @@ class Kraken2(UsbHidDriver):
 
     @property
     def supports_cooling_profiles(self):
-        return self.supports_cooling and self.firmware_version >= (3, 0, 0)
+        return self.supports_cooling and self.firmware_version[0] >= 3
 
     @property
     def firmware_version(self):
@@ -303,7 +284,7 @@ class Kraken2(UsbHidDriver):
         if clear_first:
             self.device.clear_enqueued_reports()
         msg = self.device.read(_READ_LENGTH)
-        self._firmware_version = (msg[0xb], msg[0xc] << 8 | msg[0xd], msg[0xe])
+        self._firmware_version = tuple(msg[0xb:0xf])
         return msg
 
     def _write(self, data):
