@@ -55,6 +55,18 @@ lighting channel supports up to 6 accessories and a total of 40 LEDs.
 A microphone is still present onboard for noise level optimization through CAM
 and AI.
 
+NZXT H1 V2
+----------
+
+The second revision of the NZXT H1 case, labeled H1 V2, ships with a variant of the
+NZXT Smart Device V2 that handles both the internal fans and the AIO pump. Two fan and
+one pump channels are available, where the formers can be controlled via PWM or DC.
+
+The pump speed is not user controllable. The device reports the state, speed and duty
+of each fan channel, as well as the pump speed.
+
+There are no lighting channels available nor an onboard microphone.
+
 RGB & Fan Controller
 --------------------
 
@@ -273,9 +285,13 @@ class SmartDevice(_BaseSmartDevice):
             self.device.clear_enqueued_reports()
 
         msg = self.device.read(self._READ_LENGTH)
+        fw = tuple(msg[0xb:0xf])
+        _LOGGER.debug('raw firmware version: %r', fw)
 
-        fw = '{}.{}.{}'.format(msg[0xb], msg[0xc] << 8 | msg[0xd], msg[0xe])
-        ret = [('Firmware version', fw, '')]
+        # NZXT/CAM has simplified how they report the firmware version from its
+        # raw 4-component form
+        fw_human = f'{fw[0]}.{fw[3]}'
+        ret = [('Firmware version', fw_human, '')]
 
         if self._color_channels:
             lcount = msg[0x11]
@@ -466,7 +482,8 @@ class SmartDevice2(_BaseSmartDevice):
                           for i in range(speed_channel_count)}
         color_channels = {f'led{i + 1}': (1 << i)
                           for i in range(color_channel_count)}
-        color_channels['sync'] = (1 << color_channel_count) - 1
+        if color_channels:
+            color_channels['sync'] = (1 << color_channel_count) - 1
         super().__init__(device, description, speed_channels, color_channels, **kwargs)
 
     def initialize(self, direct_access=False, **kwargs):
@@ -518,7 +535,10 @@ class SmartDevice2(_BaseSmartDevice):
                     ret.append((f'LED {c + 1} accessory {a + 1}',
                                    Hue2Accessory(accessory_id), ''))
 
-        self._read_until({b'\x11\x01': parse_firm_info, b'\x21\x03': parse_led_info})
+        parsers = {b'\x11\x01': parse_firm_info}
+        if self._color_channels:
+            parsers[b'\x21\x03'] = parse_led_info
+        self._read_until(parsers)
         return sorted(ret)
 
     def _get_status_directly(self):
@@ -589,6 +609,9 @@ class SmartDevice2(_BaseSmartDevice):
     def _write_colors(self, cid, mode, colors, sval, direction='forward',):
         mval, mod3, mod4, mincolors, maxcolors = self._COLOR_MODES[mode]
 
+        if not self._color_channels:
+            raise NotSupportedByDevice()
+
         color_count = len(colors)
         if maxcolors == 40:
             led_padding = [0x00, 0x00, 0x00]*(maxcolors - color_count)  # turn off remaining LEDs
@@ -627,6 +650,39 @@ class SmartDevice2(_BaseSmartDevice):
         self._write(msg)
 
 
+class H1V2(SmartDevice2):
+    SUPPORTED_DEVICES = [
+        (0x1e71, 0x2015, None, 'NZXT H1 V2 (experimental)', {
+            'speed_channel_count': 2,
+            'color_channel_count': 0
+        }),
+    ]
+
+    def get_status(self, direct_access=False, **kwargs):
+        ret = []
+
+        def parse_fan_info(msg):
+            mode_offset = 21
+            rpm_offset = 24
+            duty_offset = 25
+            pump_offset = 18
+            raw_modes = [None, 'DC', 'PWM']
+
+            for i, _ in enumerate(self._speed_channels):
+                mode = raw_modes[msg[mode_offset + i]]
+                ret.append((f'Fan {i + 1} speed', msg[rpm_offset] << 8 | msg[rpm_offset - 1], 'rpm'))
+                ret.append((f'Fan {i + 1} duty', msg[duty_offset], '%'))
+                ret.append((f'Fan {i + 1} control mode', mode, ''))
+                rpm_offset += 5
+                duty_offset += 5
+            ret.append(('Pump speed', msg[pump_offset] << 8 | msg[pump_offset - 1], 'rpm'))
+
+        # parse fans and pump status
+        self.device.clear_enqueued_reports()
+        self._read_until({b'\x75\x02': parse_fan_info})
+        return sorted(ret)
+
+
 # backward compatibility
 NzxtSmartDeviceDriver = SmartDevice
 SmartDeviceDriver = SmartDevice
